package org.isakiev.fileManager.archives;

import java.util.ArrayList;
import java.util.Enumeration;

/**
 * Auxiliary class representing enumeration with push back ability.
 * @author Ruslan Isakiev
 */
public class PushBackEnum<T> {
	private Enumeration<? extends T> myEntries;
	private ArrayList<T> myPushedEntries;
	
	public PushBackEnum(Enumeration<? extends T> entries) {
		myEntries = entries;
		myPushedEntries = new ArrayList<T>();
	}
	
	public void pushBackEntry(T entry) {
		myPushedEntries.add(entry);
	}
	
	public boolean hasMoreEntries() {
		return (myEntries.hasMoreElements() || myPushedEntries.size() > 0);
	}
	
	public T nextEntry() {
		T entry;
		int numberOfPushedElements = myPushedEntries.size();
		if (numberOfPushedElements == 0) {
			entry = (T) myEntries.nextElement();
		} else {
			entry = myPushedEntries.get(numberOfPushedElements - 1);
			myPushedEntries.remove(numberOfPushedElements - 1);
		}
		return entry;
	}
	
	/**
	 * For debug purposes.
	 */
	public String toString() {
		StringBuffer buffer = new StringBuffer();
		buffer.append("--- Entries ---\n");
		while (hasMoreEntries()) {
			buffer.append(nextEntry().toString()).append("\n");
		}
		buffer.append("---------------");
		return buffer.toString();
	}
}
