package org.isakiev.fileManager.contentViewers.explorer;

import javax.swing.*;
import javax.swing.tree.*;
import java.awt.Component;

import org.isakiev.fileManager.entities.IEntity;
import org.isakiev.fileManager.utils.Tools;


class ExplorerStyleTreeCellRenderer extends DefaultTreeCellRenderer{
	
	private Icon myClosedIcon;  
	private Icon myOpenedIcon;  
	
	public ExplorerStyleTreeCellRenderer() {
		super();
		myOpenedIcon = Tools.getTools().loadIcon("/resources/icon_folder_opened.gif");
		myClosedIcon = Tools.getTools().loadIcon("/resources/icon_folder_closed.gif");
	}
	
	/**
     * Configures the renderer based on the passed in components.
     * The value is set from messaging the tree with
     * <code>convertValueToText</code>, which ultimately invokes
     * <code>toString</code> on <code>value</code>.
     * The foreground color is set based on the selection and the icon
     * is set based on on leaf and expanded.
     */
   public Component getTreeCellRendererComponent(JTree tree, Object value,
						  boolean sel,
						  boolean expanded,
						  boolean leaf, int row,
						  boolean hasFocus) {
	   
	String stringValue = tree.convertValueToText(value, sel, expanded, leaf, row, hasFocus);

    //this.tree = tree;
	this.hasFocus = hasFocus;
	setText(stringValue);
	if(sel) {
	    setForeground(getTextSelectionColor());
	} else {
	    setForeground(getTextNonSelectionColor());
	}
	
	Icon icon = null;
	IEntity entity = (IEntity)value;
	if (leaf || entity.isArchiveEntity()) {
		icon = entity.getType().getIcon();
	} else {
		icon = (expanded ? myOpenedIcon : myClosedIcon);
	}
	
	// There needs to be a way to specify disabled icons.
	if (!tree.isEnabled()) {
	    setEnabled(false);
	    setDisabledIcon(icon);
	}
	else {
	    setEnabled(true);
	    setIcon(icon);
	}
    setComponentOrientation(tree.getComponentOrientation());
	selected = sel;
	return this;
   }

}
