package org.isakiev.fileManager.entities;

import java.io.File;
import java.util.zip.ZipEntry;

import org.isakiev.fileManager.entityTypes.IEntityType;

class CompressedFileEntity extends FileEntity implements ICompressedEntity {
	
	private ZipEntry myZipEntry;
	private String myShortName;

	public CompressedFileEntity(File file, ZipEntry zipEntry, IEntity parent, IEntityType type) {
		super(file, parent, type);
		myZipEntry = zipEntry;
		
		//getting short name
		String name = myZipEntry.getName();
		String separator = "/";
		if (name.endsWith(separator)) {
			name = name.substring(0,name.length() - separator.length());
		}
		int pos = name.lastIndexOf(separator);
		myShortName =  (pos == -1 ? name : name.substring(pos + separator.length())); 
	}
	
	public ZipEntry getZipEntry() {
		return myZipEntry;
	}
	
	public boolean isCompressedEntity() {
		return true;
	}
	
	
	/**
	 * Returns short entity name. It displayed in viewers.
	 * @return short entity name
	 */
	public String getShortName() {
		return myShortName;
	}
	
	/**
	 * Returns full entity name.
	 * @return full entity name.
	 */
	public String getFullName() {
		return getFile().getAbsolutePath() + File.separator + myZipEntry.getName();
	}
	
	/**
	 * Returns time when entity was last modified.
	 * @return time when entity was last modified.
	 */
	public long getLastModified() {
		return myZipEntry.getTime();
	}
	
	public long getSize() {
		return myZipEntry.getSize();
	}

}
