package org.isakiev.fileManager.entities;

import java.io.File;
import java.util.zip.ZipEntry;

import org.isakiev.fileManager.entityTypes.EntityTypeContainer;
import org.isakiev.fileManager.entityTypes.IEntityType;

/**
 * The class creates instances of all entities.
 * @author Isakiev Ruslan
 */
public class EntityFactory {
	
	/**
	 * Creates new DirEntity instance and marks it as global root.
	 * @return new DirEntity  instance
	 */
	public static IDirEntity createGlobalRootDirEntity() {
		DirEntity globalRoot = new DirEntity(new File(""), null, EntityTypeContainer.getInstance().getDirectoryType()); 
		globalRoot.markAsTreeRoot();
		return globalRoot;
	}
	
	/**
	 * Creates new DiskEntity  instance.
	 * @return new DiskEntity  instance
	 */
	public static IDiskEntity createDiskEntity(File file, IEntity parent, IEntityType type) {
		return new DiskEntity(file, parent, type);
	}
	
	/**
	 * Creates new DirEntity  instance.
	 * @return new DirEntity  instance
	 */
	public static IDirEntity createDirEntity(File file, IEntity parent, IEntityType type) {
		return new DirEntity(file, parent, type);
	}
	
	/**
	 * Creates new FileEntity  instance.
	 * @return new FileEntity  instance
	 */
	public static IFileEntity createFileEntity(File file, IEntity parent, IEntityType type) {
		return new FileEntity(file, parent, type);
	}
	
	/**
	 * Creates new ArchiveEntity instance.
	 * @return new ArchiveEntity instance
	 */
	public static IDirEntity createArchiveEntity(File file, IEntity parent, IEntityType type) {
		return new ArchiveEntity(file, parent, type);
	}
	
	/**
	 * Creates new CompressedFileEntity instance.
	 * @return new CompressedFileEntity instance
	 */
	public static IFileEntity createCompressedFileEntity(File archiveFile, ZipEntry zipEntry, IEntity parent, IEntityType type) {
		return new CompressedFileEntity(archiveFile, zipEntry, parent, type);
	}
	
	/**
	 * Creates new CompressedDirEntity instance.
	 * @return new CompressedDirEntity instance
	 */
	public static IDirEntity createCompressedDirEntity(File archiveFile, ZipEntry zipEntry, IEntity parent, IEntityType type) {
		return new CompressedDirEntity(archiveFile, zipEntry, parent, type);
	}
	
	
}
