package org.isakiev.fileManager.entityTypes;

import org.isakiev.fileManager.utils.StateLoader;
import org.isakiev.fileManager.utils.Tools;


import java.util.*;
import org.w3c.dom.*;

class EntityTypeInfoLoader {
	
	private final String myRootName = "fileFormatsInformation";
	private final String myFileFormatName = "fileFormat";
	private final String myNameName = "name";
	private final String myDescriptionName = "description";
	private final String myIconPathName = "iconPath";
	private final String myPriorityName = "priority";
	
	private final String myTypeDefinitionName = "typeDefinition";
	private final String myByFormatName = "byFormat";
	private final String myByExtensionName = "byExtension";
	
	private final String myMinFileSizeName = "minFileSize";
	private final String myKeyByteSetName = "keyByteSet";
	private final String myByteName = "byte";
	private final String myPositionName = "position";
	private final String myExtensionName = "extension";
	private final String myFileClassName = "fileClass";
	private final String myImageName = "image";
	private final String myArchiveName = "archive";
	private final String myExecutableName = "executable";
	private final String mySoundName = "sound";
	private final String myUnknownName = "unknown";
	private final String myValueName = "value";
	
	
	
	private ArrayList<AbstractType> myFileTypes;
	
	private static EntityTypeInfoLoader myInstance = null;
	
	public static EntityTypeInfoLoader getInstance() {
		if (myInstance == null) {
			myInstance = new EntityTypeInfoLoader();
		}
		return myInstance;
	}

	private EntityTypeInfoLoader() {
		myFileTypes = new ArrayList<AbstractType>();
	}
	
	public void loadInfo(String xmlFileName) {

		Document document = Tools.getTools().loadXMLDocument(xmlFileName);
		if (document == null) {
			return;
		}
		Element root = document.getDocumentElement();
		myFileTypes.clear();

		NodeList fileFormatsList = root.getElementsByTagName(myFileFormatName);
		for (int i = 0; i < fileFormatsList.getLength(); i++) {
			AutomaticallyGeneratedType fileType = new AutomaticallyGeneratedType();
			NamedNodeMap attrs = fileFormatsList.item(i).getAttributes();
			fileType.setName(attrs.getNamedItem(myNameName).getNodeValue());
			fileType.setDescription(attrs.getNamedItem(myDescriptionName).getNodeValue());
			fileType.setIcon(attrs.getNamedItem(myIconPathName).getNodeValue());
			fileType.setPriority(Integer.parseInt(attrs.getNamedItem(myPriorityName).getNodeValue()));
			
			NodeList content = fileFormatsList.item(i).getChildNodes();
			for (int j=0; j<content.getLength(); j++) {
				Node item = content.item(j);
				String childName = item.getNodeName();

				if (childName.equals(myTypeDefinitionName)) {
					fileType.setDefineByFormat(getValue(item).equals(myByFormatName));
				}
				if (childName.equals(myMinFileSizeName)) {
					fileType.setMinFileSize(Integer.parseInt(getValue(item)));
				}
				if (childName.equals(myKeyByteSetName)) {
					NodeList keyBytes = item.getChildNodes();
					for (int k=0; k<keyBytes.getLength(); k++) {
						Node keyByteItem = keyBytes.item(k);
						if (keyByteItem.getNodeName().equals(myByteName)) {
							int bytePosition = Integer.parseInt(keyByteItem.getAttributes().getNamedItem(myPositionName).getNodeValue());
							int byteValue = Integer.parseInt(keyByteItem.getAttributes().getNamedItem(myValueName).getNodeValue(),16);
							fileType.addKeyByte(bytePosition, byteValue);
						}
					}
				}
				if (childName.equals(myExtensionName)) {
					fileType.setExtension(getValue(item));
				}
				if (childName.equals(myFileClassName)) {
					if (getValue(item).equals(myImageName)) {
						fileType.setViewer(ImageViewer.getInstance());
					}
					if (getValue(item).equals(myArchiveName)) {
						fileType.setViewer(EmptyViewer.getInstance());
						fileType.setArchiveFlag(true);
					}
					if (getValue(item).equals(myExecutableName)) {
						fileType.setViewer(ExecutableFileViewer.getInstance());
						fileType.setExecutableFlag(true);
					}
				}

			}
			myFileTypes.add(fileType);
		}
		
	} 
	
	private String getValue(Node node) {
		return node.getAttributes().getNamedItem(myValueName).getNodeValue();
	}
	
	public Collection<AbstractType> getFileTypes() {
		return Collections.unmodifiableCollection(myFileTypes);
	}
}
