package org.isakiev.fileManager.tests;

import junit.framework.TestCase;
import java.io.File;
import java.util.*;

import org.isakiev.fileManager.contentManagers.*;
import org.isakiev.fileManager.contentModel.ContentModel;
import org.isakiev.fileManager.contentModel.IContentModel;
import org.isakiev.fileManager.entities.*;


/**
 * Content manager tests.
 * @author Isakiev Ruslan 
 */
public class TestContentManager extends TestCase {
	
	private ArrayList<File> splitPath(String path) {
		ArrayList<File> result = new ArrayList<File>();
		File current = new File(path);
		do {
			result.add(current);
			current = current.getParentFile();
		} while (current != null); 

		return result;
	}
	
	/**
	 * Checks if there is path to the current directory.
	 */
	public void testCurrentDirectoryPath() {
		IContentModel model = new ContentModel(new ContentManager());
		String userDir = System.getProperty("user.dir");
		if (userDir == null) 
			fail("Can't get system property 'user.dir'");
		
		ArrayList<File> pathElements = splitPath(userDir);
		ListIterator<File> iter = pathElements.listIterator(pathElements.size());
		
		IDirEntity root = model.getRoot();
		List<IEntity> children = root.getChildren(); 
		
		while (iter.hasPrevious()) {
			File current = iter.previous();
			//System.out.print(current);
			boolean found = false;
			for (IEntity entity:children) {
				if (entity.getFile().getAbsoluteFile().equals(current.getAbsoluteFile())) {
					current = entity.getFile();
					children = model.getChildren((IDirEntity)entity);
					found = true;
					break;
				}
			}
			if (!found) {
				fail("Can't reach current user's directory.");
			} 
		}
		
	}
}
