package org.isakiev.fileManager.tests;

import junit.framework.TestCase;

import org.isakiev.fileManager.entities.*;
import java.io.File;

/**
 * Entity tests. 
 * @author Isakiev Ruslan
 */
public class TestEntities extends TestCase {
	
	/**
	 * Tests if file entities are correctly defined.
	 */
	public void testFileEntityType() {
		IEntity file = EntityFactory.createFileEntity(new File(""), null,null);
		if ( !file.isFileEntity() || file.isDirEntity() || file.isDiskEntity()) {
			fail("FileEntity: Incorrect type of the entity"); 
		}
	}
	
	/**
	 * Tests if directory entities are correctly defined.
	 */
	public void testDirEntityType() {
		IEntity dir = EntityFactory.createDirEntity(new File(""), null, null);
		if ( dir.isFileEntity() || !dir.isDirEntity() || dir.isDiskEntity()) {
			fail("DirEntity: Incorrect type of the entity"); 
		}
	}
	
	/**
	 * Tests if disk entities are correctly defined.
	 */
	public void testDiskEntityType() {
		IEntity disk = EntityFactory.createDiskEntity(new File(""), null, null);
		if ( disk.isFileEntity() || disk.isDirEntity() || !disk.isDiskEntity()) {
			fail("DiskEntity: Incorrect type of the entity"); 
		}
	}
	
	/**
	 * Tests entity comparator (dir&dir).
	 */
	public void testEntityComparator1() {

		EntityComparator<IEntity> comparator = new EntityComparator<IEntity>();
		IEntity dir1 = EntityFactory.createDirEntity(new File("aaa"), null, null);
		IEntity dir2 = EntityFactory.createDirEntity(new File("bbb"), null, null);
		
		assertTrue("Incorrect comparing (dir&dir)", comparator.compare(dir1,dir2) == -1);
	}
	
	/**
	 * Tests entity comparator (file&dir).
	 */
	public void testEntityComparator2() {

		EntityComparator<IEntity> comparator = new EntityComparator<IEntity>();
		IEntity dir2 = EntityFactory.createDirEntity(new File("bbb"), null, null);
		IEntity file1 = EntityFactory.createFileEntity(new File("c.cc"), null,null);
		
		assertTrue("Incorrect comparing (file&dir)", comparator.compare(file1,dir2) == 1);
	}
	
	/**
	 * Tests entity comparator (file&file).
	 */
	public void testEntityComparator3() {

		EntityComparator<IEntity> comparator = new EntityComparator<IEntity>();
		IEntity file1 = EntityFactory.createFileEntity(new File("c.cc"), null,null);
		IEntity file2 = EntityFactory.createFileEntity(new File("d.dd"), null,null);
		
		assertTrue("Incorrect comparing (file&file)", comparator.compare(file1,file2) == -1);
	}
	
	/**
	 * Tests entity comparator (2 equal entities).
	 */
	public void testEntityComparator4() {

		EntityComparator<IEntity> comparator = new EntityComparator<IEntity>();
		IEntity file2 = EntityFactory.createFileEntity(new File("d.dd"), null,null);
		IEntity file3 = EntityFactory.createFileEntity(new File("d.dd"), null,null);
		
		assertTrue("Incorrect comparing (2 equal entities)", comparator.compare(file2,file3) == 0);
	}
}
