package org.isakiev.fileManager.utils;

import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;
import java.util.List;

public class InfoFrame extends JFrame {
	
	private JTabbedPane myMainTabbedPane;
	private JTabbedPane myAboutTabbedPane;
	private JTabbedPane mySettingsTabbedPane;
	
	private JPanel myVersionHistoryPanel;
	private JPanel myFeaturesListPanel;
	private JPanel myHotKeysPanel;
	private JPanel myAuthorPanel;
	
	public static int FEATURES = 1;
	public static int HOT_KEYS = 2;
	public static int AUTHOR = 3;
	
	public InfoFrame(Component parentComponent, int activeTab) {
		super("Info");
		setDefaultCloseOperation(HIDE_ON_CLOSE);
		
		myVersionHistoryPanel = createVersionHistoryPanel();
		myFeaturesListPanel = createFeaturesListPanel();
		myHotKeysPanel = createHotKeysPanel();
		myAuthorPanel = createAuthorPanel();
		
		myAboutTabbedPane = new JTabbedPane(JTabbedPane.TOP, JTabbedPane.WRAP_TAB_LAYOUT);
		myAboutTabbedPane.addTab("Features", myFeaturesListPanel);
		//myAboutTabbedPane.addTab("Version history", myVersionHistoryPanel);
		//myAboutTabbedPane.addTab("Statistics", new JPanel());
		myAboutTabbedPane.addTab("Hot keys", myHotKeysPanel);
		myAboutTabbedPane.addTab("About", myAuthorPanel);
		
		
		mySettingsTabbedPane = new JTabbedPane(JTabbedPane.TOP, JTabbedPane.WRAP_TAB_LAYOUT);
		mySettingsTabbedPane.addTab("File associations",  new JPanel());
		
		myMainTabbedPane = new JTabbedPane(JTabbedPane.TOP, JTabbedPane.WRAP_TAB_LAYOUT);
		myMainTabbedPane.addTab("About", myAboutTabbedPane);
		//myMainTabbedPane.addTab("Settings", mySettingsTabbedPane);
		
		add(myMainTabbedPane);
		
		myMainTabbedPane.setSelectedComponent(myAboutTabbedPane);
		
		setSize(510,300);
		if (parentComponent != null) {
			int x = parentComponent.getLocation().x + (parentComponent.getWidth() - this.getWidth())/2;
			int y = parentComponent.getLocation().y + (parentComponent.getHeight() - this.getHeight())/2;
			setLocation(x,y);
		}
		
		if (activeTab == FEATURES) {
			myAboutTabbedPane.setSelectedComponent(myFeaturesListPanel);
		} else if (activeTab == HOT_KEYS) {
			myAboutTabbedPane.setSelectedComponent(myHotKeysPanel);
		} else if (activeTab == AUTHOR) {
			myAboutTabbedPane.setSelectedComponent(myAuthorPanel);
		}

		setVisible(true);
	}
	
	private JPanel createVersionHistoryPanel() {
		JPanel panel = new JPanel();
		List<InfoLoader.Info> list = InfoLoader.getInstance().getInfo();
		//isn't effective, but the list is not so big.
		for (int i=list.size()-1; i>=0; i--) {
			
		}
		return panel;
	}
	
	private JPanel createFeaturesListPanel() {
		JPanel panel = new JPanel();
		panel.setLayout(new BorderLayout());
		StringBuffer buffer = new StringBuffer();
		buffer.append("<html><ul>");
		for (String s:InfoLoader.getInstance().getFeatures()) {
			buffer.append("<li>").append(s).append("</li>");
		}
		buffer.append("</ul></html>");
		JLabel label = new JLabel(buffer.toString());
		label.setFont(Settings.getInstance().getInfoFont());
		label.setAlignmentX(JComponent.LEFT_ALIGNMENT);
		label.setAlignmentY(JComponent.TOP_ALIGNMENT);
		panel.add(label, BorderLayout.PAGE_START);
		return panel;
	}
	
	private JPanel createAuthorPanel() {
		JPanel panel = new JPanel();
		panel.setLayout(new GridLayout(1,1));
		StringBuffer buffer = new StringBuffer();
		buffer.append("<html><table><tr><td>&nbsp;</td>");
		buffer.append("<td>File Manager<br>");
		buffer.append("version 1.6<br>");
		buffer.append("(c) Ruslan Isakiev<br>");
		buffer.append("rdx@yandex.ru</td><td>&nbsp;</td></tr></html>");
		JLabel label = new JLabel(buffer.toString());
		label.setFont(Settings.getInstance().getInfoFont());
		label.setAlignmentX(JComponent.CENTER_ALIGNMENT);
		panel.add(label);
		return panel;
	}
	
	private JPanel createHotKeysPanel() {
		JPanel panel = new JPanel();
		panel.setLayout(new GridLayout(1,1));
		StringBuffer buffer = new StringBuffer();
		buffer.append("<html><table><tr><td>&nbsp;</td>");
		buffer.append("<td>Hot keys (in NC style interface):<br><br>");
		buffer.append("F5 - Copy<br>");
		buffer.append("F6 - Rename/move<br>");
		buffer.append("F7 - Create the directory<br>");
		buffer.append("F8, Delete - Delete<br>");
		buffer.append("Alt+F1 - Select root directory in the left panel<br>");
		buffer.append("Alt+F2 - Select root directory in the right panel<br>");
		buffer.append("Alt+S - Select the same directory in the not active panel");
		buffer.append("</td><td>&nbsp;</td></tr></html>");
		JLabel label = new JLabel(buffer.toString());
		label.setFont(Settings.getInstance().getInfoFont());
		label.setAlignmentX(JComponent.CENTER_ALIGNMENT);
		panel.add(label);
		return panel;
	}
	
}
